Result

Type Alias Result 

pub type Result<T> = Result<T, Error>;
A custom Result type that returns Error in case of failure.

This type is used for handling errors related to shell operations. It wraps the standard Result type but replaces the error type with our custom Error type.

Aliased Type

pub enum Result<T> {
    Ok(T),
    Err(Error),
}

Variants

1.0.0

Ok(T)

Contains the success value

1.0.0

Err(Error)

Contains the error value